@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
 our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.05 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.06 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -49,37 +49,41 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.04
+L<Perl::Examples::Accessors::Array> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.04
+L<Perl::Examples::Accessors::ClassAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.04
+L<Perl::Examples::Accessors::ClassInsideOut> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::Hash> 0.04
+L<Perl::Examples::Accessors::Hash> 0.05
 
-L<Perl::Examples::Accessors::Mo> 0.04
+L<Perl::Examples::Accessors::Mo> 0.05
 
-L<Perl::Examples::Accessors::Moo> 0.04
+L<Perl::Examples::Accessors::MojoBase> 0.05
 
-L<Perl::Examples::Accessors::Moose> 0.04
+L<Perl::Examples::Accessors::Moo> 0.05
 
-L<Perl::Examples::Accessors::Mouse> 0.04
+L<Perl::Examples::Accessors::Moose> 0.05
 
-L<Perl::Examples::Accessors::Scalar> 0.04
+L<Perl::Examples::Accessors::Mouse> 0.05
+
+L<Perl::Examples::Accessors::ObjectSimple> 0.05
+
+L<Perl::Examples::Accessors::Scalar> 0.05
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
+=item * Perl::Examples::Accessors::Mouse (perl_code)
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray>
+L<Perl::Examples::Accessors::Mouse>
 
 
 
@@ -89,21 +93,9 @@ L<Perl::Examples::Accessors::ClassAccessorArray>
 
 
 
-=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
+=item * Perl::Examples::Accessors::MojoBase (perl_code)
 
-L<Perl::Examples::Accessors::ClassAccessor>
-
-
-
-=item * Perl::Examples::Accessors::Moo (perl_code)
-
-L<Perl::Examples::Accessors::Moo>
-
-
-
-=item * Perl::Examples::Accessors::Hash (perl_code)
-
-L<Perl::Examples::Accessors::Hash>
+L<Perl::Examples::Accessors::MojoBase>
 
 
 
@@ -113,9 +105,9 @@ L<Perl::Examples::Accessors::ClassXSAccessor>
 
 
 
-=item * Perl::Examples::Accessors::Mouse (perl_code)
+=item * Perl::Examples::Accessors::Moo (perl_code)
 
-L<Perl::Examples::Accessors::Mouse>
+L<Perl::Examples::Accessors::Moo>
 
 
 
@@ -125,9 +117,9 @@ L<Perl::Examples::Accessors::Array>
 
 
 
-=item * Perl::Examples::Accessors::Moose (perl_code)
+=item * Perl::Examples::Accessors::Mo (perl_code)
 
-L<Perl::Examples::Accessors::Moose>
+L<Perl::Examples::Accessors::Mo>
 
 
 
@@ -137,9 +129,21 @@ L<Perl::Examples::Accessors::Scalar>
 
 
 
-=item * Perl::Examples::Accessors::Mo (perl_code)
+=item * Perl::Examples::Accessors::Moose (perl_code)
 
-L<Perl::Examples::Accessors::Mo>
+L<Perl::Examples::Accessors::Moose>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessorArray>
+
+
+
+=item * Perl::Examples::Accessors::Hash (perl_code)
+
+L<Perl::Examples::Accessors::Hash>
 
 
 
@@ -149,6 +153,18 @@ L<Perl::Examples::Accessors::ClassInsideOut>
 
 
 
+=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
+
+L<Perl::Examples::Accessors::ObjectSimple>
+
+
+
+=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassAccessor>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -160,19 +176,21 @@ Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
  | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
- | Perl::Examples::Accessors::Moose                | 114       | 111.5                  | 1          | 0.00011 | 20      |
- | Perl::Examples::Accessors::Moo                  | 21        | 18.5                   | 5.3        | 4.3e-05 | 22      |
- | Perl::Examples::Accessors::Mouse                | 17        | 14.5                   | 6.6        | 7.3e-05 | 20      |
- | Perl::Examples::Accessors::ClassInsideOut       | 10        | 7.5                    | 11         | 1.1e-05 | 20      |
- | Perl::Examples::Accessors::ClassXSAccessorArray | 7.9       | 5.4                    | 14         | 2e-05   | 20      |
- | Perl::Examples::Accessors::ClassAccessor        | 7.5       | 5                      | 15         | 1.8e-05 | 20      |
- | Perl::Examples::Accessors::ClassXSAccessor      | 7.4       | 4.9                    | 15         | 1.7e-05 | 20      |
- | Perl::Examples::Accessors::Mo                   | 4.1       | 1.6                    | 28         | 1e-05   | 20      |
- | Perl::Examples::Accessors::ClassAccessorArray   | 4.1       | 1.6                    | 28         | 1.5e-05 | 20      |
- | Perl::Examples::Accessors::Array                | 2.8       | 0.3                    | 40         | 1.6e-05 | 20      |
- | Perl::Examples::Accessors::Hash                 | 2.8       | 0.3                    | 40         | 2e-05   | 20      |
- | Perl::Examples::Accessors::Scalar               | 2.7       | 0.2                    | 42         | 1.1e-05 | 20      |
- | perl -e1 (baseline)                             | 2.5       | 0                      | 45         | 4.5e-06 | 20      |
+ | Perl::Examples::Accessors::Moose                | 1.2e+02   | 117.5                  | 1          | 0.00054 | 20      |
+ | Perl::Examples::Accessors::Moo                  | 21        | 18.5                   | 5.4        | 8.3e-05 | 20      |
+ | Perl::Examples::Accessors::Mouse                | 17        | 14.5                   | 6.8        | 3.1e-05 | 20      |
+ | Perl::Examples::Accessors::ClassInsideOut       | 10        | 7.5                    | 11         | 2.7e-05 | 20      |
+ | Perl::Examples::Accessors::MojoBase             | 10        | 7.5                    | 11         | 2.9e-05 | 20      |
+ | Perl::Examples::Accessors::ClassXSAccessorArray | 8.1       | 5.6                    | 14         | 5.8e-05 | 22      |
+ | Perl::Examples::Accessors::ObjectSimple         | 7.7       | 5.2                    | 15         | 2.9e-05 | 20      |
+ | Perl::Examples::Accessors::ClassAccessor        | 7.7       | 5.2                    | 15         | 6e-05   | 20      |
+ | Perl::Examples::Accessors::ClassXSAccessor      | 7.4       | 4.9                    | 16         | 1.4e-05 | 23      |
+ | Perl::Examples::Accessors::ClassAccessorArray   | 4.2       | 1.7                    | 28         | 3.2e-05 | 22      |
+ | Perl::Examples::Accessors::Mo                   | 4.2       | 1.7                    | 28         | 2e-05   | 20      |
+ | Perl::Examples::Accessors::Scalar               | 2.7       | 0.2                    | 43         | 1.5e-05 | 20      |
+ | Perl::Examples::Accessors::Array                | 2.7       | 0.2                    | 43         | 1.8e-05 | 20      |
+ | Perl::Examples::Accessors::Hash                 | 2.7       | 0.2                    | 44         | 1.3e-05 | 21      |
+ | perl -e1 (baseline)                             | 2.5       | 0                      | 47         | 6.6e-06 | 21      |
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
