@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
 our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -10,7 +10,7 @@ my $classes = \%Bencher::ScenarioUtil::Accessors::classes;
 our $scenario = {
     summary => 'Benchmark object construction',
     modules => {
-        'Perl::Examples::Accessors' => {version=>0.04},
+        'Perl::Examples::Accessors' => {version=>0.05},
     },
     participants => [
         map {
@@ -40,7 +40,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.05 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.06 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -58,41 +58,45 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors> 0.04
+L<Perl::Examples::Accessors> 0.05
 
-L<Perl::Examples::Accessors::Array> 0.04
+L<Perl::Examples::Accessors::Array> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.04
+L<Perl::Examples::Accessors::ClassAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.04
+L<Perl::Examples::Accessors::ClassInsideOut> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::Hash> 0.04
+L<Perl::Examples::Accessors::Hash> 0.05
 
-L<Perl::Examples::Accessors::Mo> 0.04
+L<Perl::Examples::Accessors::Mo> 0.05
 
-L<Perl::Examples::Accessors::Moo> 0.04
+L<Perl::Examples::Accessors::MojoBase> 0.05
 
-L<Perl::Examples::Accessors::Moose> 0.04
+L<Perl::Examples::Accessors::Moo> 0.05
 
-L<Perl::Examples::Accessors::Mouse> 0.04
+L<Perl::Examples::Accessors::Moose> 0.05
 
-L<Perl::Examples::Accessors::Scalar> 0.04
+L<Perl::Examples::Accessors::Mouse> 0.05
+
+L<Perl::Examples::Accessors::ObjectSimple> 0.05
+
+L<Perl::Examples::Accessors::Scalar> 0.05
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Mouse (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassXSAccessorArray->new
+ Perl::Examples::Accessors::Mouse->new
 
 
 
@@ -104,27 +108,11 @@ Code template:
 
 
 
-=item * Class::Accessor (perl_code)
+=item * Mojo::Base (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassAccessor->new
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moo->new
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Hash->new
+ Perl::Examples::Accessors::MojoBase->new
 
 
 
@@ -136,11 +124,11 @@ Code template:
 
 
 
-=item * Mouse (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Mouse->new
+ Perl::Examples::Accessors::Moo->new
 
 
 
@@ -152,11 +140,11 @@ Code template:
 
 
 
-=item * Moose (perl_code)
+=item * Mo (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Moose->new
+ Perl::Examples::Accessors::Mo->new
 
 
 
@@ -168,11 +156,27 @@ Code template:
 
 
 
-=item * Mo (perl_code)
+=item * Moose (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Mo->new
+ Perl::Examples::Accessors::Moose->new
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessorArray->new
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
 
 
 
@@ -184,6 +188,22 @@ Code template:
 
 
 
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ObjectSimple->new
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessor->new
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -195,18 +215,20 @@ Benchmark with default options (C<< bencher -m Accessors::Construction >>):
  +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
  | participant                 | rate (/s)   | time (μs) | vs_slowest | result_size (b) | errors  | samples |
  +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
- | Class::InsideOut            | 3.9e+05     | 2.6       | 1          | 144             | 3.3e-09 | 20      |
- | Moose                       | 9.2495e+05  | 1.0811    | 2.3846     | 120             | 9.2e-12 | 22      |
- | Mo                          | 1.3e+06     | 0.77      | 3.4        | 120             | 1.7e-09 | 20      |
- | Moo                         | 1.667e+06   | 0.5998    | 4.298      | 120             | 1.1e-11 | 20      |
- | Class::Accessor             | 1.81e+06    | 0.5525    | 4.667      | 120             | 1e-11   | 20      |
- | Mouse                       | 2.06e+06    | 0.485     | 5.31       | 120             | 1.8e-10 | 26      |
- | no generator (array-based)  | 2.54975e+06 | 0.392196  | 6.57354    | 64              | 0       | 20      |
- | no generator (hash-based)   | 3.033e+06   | 0.3297    | 7.821      | 120             | 1.2e-11 | 20      |
- | no generator (scalar-based) | 3.37e+06    | 0.297     | 8.69       | 72              | 1e-10   | 22      |
- | Class::Accessor::Array      | 3.45e+06    | 0.29      | 8.89       | 64              | 8.6e-11 | 30      |
- | Class::XSAccessor           | 5.125e+06   | 0.1951    | 13.21      | 120             | 9.4e-12 | 20      |
- | Class::XSAccessor::Array    | 5.26e+06    | 0.19      | 13.6       | 64              | 1e-10   | 20      |
+ | Class::InsideOut            | 3.9e+05     | 2.6       | 1          | 144             | 6.7e-09 | 20      |
+ | Moose                       | 9.4e+05     | 1.1       | 2.4        | 120             | 1.7e-09 | 20      |
+ | Mo                          | 1.29865e+06 | 0.770029  | 3.36094    | 120             | 0       | 20      |
+ | Moo                         | 1.66899e+06 | 0.599166  | 4.31938    | 120             | 0       | 20      |
+ | Class::Accessor             | 1.81e+06    | 0.552     | 4.69       | 120             | 1.9e-10 | 23      |
+ | Mouse                       | 1.89e+06    | 0.53      | 4.89       | 120             | 1.8e-10 | 28      |
+ | no generator (array-based)  | 2.52e+06    | 0.397     | 6.52       | 64              | 1.6e-10 | 33      |
+ | no generator (hash-based)   | 3.00673e+06 | 0.332587  | 7.78149    | 120             | 0       | 20      |
+ | Object::Simple              | 3.06127e+06 | 0.326661  | 7.92265    | 120             | 0       | 20      |
+ | Mojo::Base                  | 3.07997e+06 | 0.324679  | 7.97103    | 120             | 0       | 20      |
+ | no generator (scalar-based) | 3.35e+06    | 0.298     | 8.67       | 72              | 1e-10   | 20      |
+ | Class::Accessor::Array      | 3.38e+06    | 0.296     | 8.75       | 64              | 8.2e-11 | 32      |
+ | Class::XSAccessor           | 5.05885e+06 | 0.197673  | 13.0924    | 120             | 0       | 20      |
+ | Class::XSAccessor::Array    | 5.26215e+06 | 0.190036  | 13.6186    | 64              | 0       | 20      |
  +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
 
 =head1 DESCRIPTION
