@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Get;
 
 our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Get - Benchmark attribute read/get
 
 =head1 VERSION
 
-This document describes version 0.05 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.06 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -68,37 +68,41 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.04
+L<Perl::Examples::Accessors::Array> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.04
+L<Perl::Examples::Accessors::ClassAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.04
+L<Perl::Examples::Accessors::ClassInsideOut> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::Hash> 0.04
+L<Perl::Examples::Accessors::Hash> 0.05
 
-L<Perl::Examples::Accessors::Mo> 0.04
+L<Perl::Examples::Accessors::Mo> 0.05
 
-L<Perl::Examples::Accessors::Moo> 0.04
+L<Perl::Examples::Accessors::MojoBase> 0.05
 
-L<Perl::Examples::Accessors::Moose> 0.04
+L<Perl::Examples::Accessors::Moo> 0.05
 
-L<Perl::Examples::Accessors::Mouse> 0.04
+L<Perl::Examples::Accessors::Moose> 0.05
+
+L<Perl::Examples::Accessors::Mouse> 0.05
+
+L<Perl::Examples::Accessors::ObjectSimple> 0.05
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Mouse (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -110,27 +114,11 @@ Code template:
 
 
 
-=item * Class::Accessor (perl_code)
+=item * Mojo::Base (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -142,11 +130,11 @@ Code template:
 
 
 
-=item * Mouse (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -158,14 +146,6 @@ Code template:
 
 
 
-=item * Moose (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o->attr1(42); $o }; $o->attr1
-
-
-
 =item * Mo (perl_code)
 
 Code template:
@@ -174,6 +154,30 @@ Code template:
 
 
 
+=item * Moose (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * Class::InsideOut (perl_code)
 
 Code template:
@@ -182,6 +186,22 @@ Code template:
 
 
 
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * raw hash access (perl_code)
 
 Code template:
@@ -206,23 +226,25 @@ Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 
 Benchmark with default options (C<< bencher -m Accessors::Get >>):
 
- +----------------------------+-----------+-----------+------------+---------+---------+
- | participant                | rate (/s) | time (ns) | vs_slowest | errors  | samples |
- +----------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor            | 2.362e+06 | 423.4     | 1          | 9.4e-12 | 20      |
- | Class::InsideOut           | 3.736e+06 | 267.7     | 1.582      | 9.1e-12 | 20      |
- | no generator (hash-based)  | 5.636e+06 | 177.4     | 2.387      | 1.1e-11 | 20      |
- | no generator (array-based) | 5.7e+06   | 1.7e+02   | 2.4        | 2.4e-10 | 33      |
- | Mo                         | 5.817e+06 | 171.9     | 2.463      | 8.9e-12 | 20      |
- | Moose                      | 6.7e+06   | 1.5e+02   | 2.9        | 4.2e-10 | 20      |
- | Class::Accessor::Array     | 7.148e+06 | 139.9     | 3.027      | 9.3e-12 | 20      |
- | Mouse                      | 1.27e+07  | 78.6      | 5.39       | 1.1e-11 | 20      |
- | Class::XSAccessor          | 1.4e+07   | 73        | 5.8        | 2e-10   | 21      |
- | Moo                        | 1.58e+07  | 63.4      | 6.68       | 9.4e-12 | 22      |
- | Class::XSAccessor::Array   | 1.85e+07  | 54        | 7.84       | 4.7e-11 | 26      |
- | raw hash access            | 3.4e+07   | 29        | 14         | 1e-10   | 20      |
- | raw array access           | 4.78e+07  | 20.9      | 20.2       | 9.4e-12 | 20      |
- +----------------------------+-----------+-----------+------------+---------+---------+
+ +----------------------------+-------------+-----------+------------+---------+---------+
+ | participant                | rate (/s)   | time (ns) | vs_slowest | errors  | samples |
+ +----------------------------+-------------+-----------+------------+---------+---------+
+ | Class::Accessor            | 2.36532e+06 | 422.776   | 1          | 0       | 21      |
+ | Class::InsideOut           | 3.7e+06     | 2.7e+02   | 1.5        | 3.3e-10 | 31      |
+ | Mojo::Base                 | 5.54943e+06 | 180.199   | 2.34617    | 0       | 20      |
+ | no generator (hash-based)  | 5.6e+06     | 1.8e+02   | 2.4        | 3e-10   | 21      |
+ | Mo                         | 5.91e+06    | 169       | 2.5        | 1e-10   | 20      |
+ | no generator (array-based) | 5.9e+06     | 1.7e+02   | 2.5        | 4.2e-10 | 20      |
+ | Object::Simple             | 6.07934e+06 | 164.492   | 2.5702     | 0       | 20      |
+ | Moose                      | 6.78218e+06 | 147.445   | 2.86734    | 0       | 22      |
+ | Class::Accessor::Array     | 7.39237e+06 | 135.275   | 3.12532    | 0       | 20      |
+ | Mouse                      | 1.35e+07    | 74.1      | 5.71       | 1.1e-11 | 33      |
+ | Moo                        | 1.7e+07     | 59        | 7.2        | 1.5e-10 | 23      |
+ | Class::XSAccessor          | 1.82681e+07 | 54.7401   | 7.72333    | 0       | 28      |
+ | Class::XSAccessor::Array   | 2.20255e+07 | 45.402    | 9.31184    | 0       | 20      |
+ | raw hash access            | 3.06869e+07 | 32.5872   | 12.9737    | 0       | 31      |
+ | raw array access           | 4.78931e+07 | 20.8798   | 20.2481    | 0       | 22      |
+ +----------------------------+-------------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
