@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Set;
 
 our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Set - Benchmark attribute write/set
 
 =head1 VERSION
 
-This document describes version 0.05 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.06 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -68,37 +68,41 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.04
+L<Perl::Examples::Accessors::Array> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.04
+L<Perl::Examples::Accessors::ClassAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.04
+L<Perl::Examples::Accessors::ClassInsideOut> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.05
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.04
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.05
 
-L<Perl::Examples::Accessors::Hash> 0.04
+L<Perl::Examples::Accessors::Hash> 0.05
 
-L<Perl::Examples::Accessors::Mo> 0.04
+L<Perl::Examples::Accessors::Mo> 0.05
 
-L<Perl::Examples::Accessors::Moo> 0.04
+L<Perl::Examples::Accessors::MojoBase> 0.05
 
-L<Perl::Examples::Accessors::Moose> 0.04
+L<Perl::Examples::Accessors::Moo> 0.05
 
-L<Perl::Examples::Accessors::Mouse> 0.04
+L<Perl::Examples::Accessors::Moose> 0.05
+
+L<Perl::Examples::Accessors::Mouse> 0.05
+
+L<Perl::Examples::Accessors::ObjectSimple> 0.05
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Mouse (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
 
 
 
@@ -110,27 +114,11 @@ Code template:
 
 
 
-=item * Class::Accessor (perl_code)
+=item * Mojo::Base (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o }; $o->attr1(42)
 
 
 
@@ -142,11 +130,11 @@ Code template:
 
 
 
-=item * Mouse (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
 
 
 
@@ -158,14 +146,6 @@ Code template:
 
 
 
-=item * Moose (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
-
-
-
 =item * Mo (perl_code)
 
 Code template:
@@ -174,6 +154,30 @@ Code template:
 
 
 
+=item * Moose (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
 =item * Class::InsideOut (perl_code)
 
 Code template:
@@ -182,6 +186,22 @@ Code template:
 
 
 
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
+
+
+
 =item * raw hash access (perl_code)
 
 Code template:
@@ -206,23 +226,25 @@ Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 
 Benchmark with default options (C<< bencher -m Accessors::Set >>):
 
- +----------------------------+-----------+-----------+------------+---------+---------+
- | participant                | rate (/s) | time (ns) | vs_slowest | errors  | samples |
- +----------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor            | 1.89e+06  | 529       | 1          | 9.6e-12 | 20      |
- | Class::InsideOut           | 3.08e+06  | 325       | 1.63       | 2.9e-10 | 23      |
- | no generator (hash-based)  | 4.461e+06 | 224.2     | 2.36       | 1.1e-11 | 20      |
- | no generator (array-based) | 4.876e+06 | 205.1     | 2.58       | 9e-12   | 20      |
- | Moose                      | 5.123e+06 | 195.2     | 2.71       | 8.9e-12 | 20      |
- | Mo                         | 5.2e+06   | 1.9e+02   | 2.8        | 3e-10   | 21      |
- | Class::Accessor::Array     | 5.6e+06   | 1.8e+02   | 3          | 2.8e-10 | 25      |
- | Mouse                      | 1.1e+07   | 92        | 5.8        | 2.1e-10 | 20      |
- | Class::XSAccessor          | 1.18e+07  | 85.1      | 6.22       | 5.3e-11 | 20      |
- | Moo                        | 1.3e+07   | 78        | 6.8        | 2.1e-10 | 20      |
- | Class::XSAccessor::Array   | 1.4e+07   | 71        | 7.5        | 2e-10   | 21      |
- | raw hash access            | 2.33e+07  | 42.9      | 12.3       | 1.1e-11 | 20      |
- | raw array access           | 2.94e+07  | 34        | 15.6       | 1e-11   | 20      |
- +----------------------------+-----------+-----------+------------+---------+---------+
+ +----------------------------+-------------+-----------+------------+---------+---------+
+ | participant                | rate (/s)   | time (ns) | vs_slowest | errors  | samples |
+ +----------------------------+-------------+-----------+------------+---------+---------+
+ | Class::Accessor            | 1.8e+06     | 5.5e+02   | 1          | 6.2e-10 | 20      |
+ | Class::InsideOut           | 3.04133e+06 | 328.803   | 1.67054    | 0       | 20      |
+ | no generator (hash-based)  | 4.5e+06     | 222       | 2.47       | 1e-10   | 20      |
+ | no generator (array-based) | 4.95e+06    | 202       | 2.72       | 1e-10   | 20      |
+ | Mojo::Base                 | 5.1e+06     | 1.9e+02   | 2.8        | 4.1e-10 | 21      |
+ | Moose                      | 5.20602e+06 | 192.085   | 2.85956    | 0       | 20      |
+ | Mo                         | 5.37543e+06 | 186.032   | 2.95261    | 0       | 20      |
+ | Class::Accessor::Array     | 5.64654e+06 | 177.099   | 3.10153    | 0       | 22      |
+ | Object::Simple             | 5.73427e+06 | 174.39    | 3.14972    | 0       | 20      |
+ | Mouse                      | 8.5e+06     | 118       | 4.67       | 5.2e-11 | 20      |
+ | Class::XSAccessor          | 1.2e+07     | 81        | 6.8        | 2.1e-10 | 20      |
+ | Moo                        | 1.27e+07    | 78.8      | 6.97       | 5.2e-11 | 20      |
+ | Class::XSAccessor::Array   | 1.4e+07     | 69        | 7.9        | 1.8e-10 | 27      |
+ | raw hash access            | 2.2e+07     | 45        | 12         | 1.5e-10 | 37      |
+ | raw array access           | 2.72783e+07 | 36.6592   | 14.9834    | 0       | 20      |
+ +----------------------------+-------------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
